@@ -1,12 +1,12 @@
 package PlugAuth;
 
 # ABSTRACT: Pluggable authentication and authorization server.
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 use base 'Clustericious::App';
 use PlugAuth::Routes;
 use Log::Log4perl qw( :easy );
@@ -187,7 +187,7 @@ PlugAuth - Pluggable authentication and authorization server.
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
