@@ -2,7 +2,7 @@ package PlugAuth::Plugin::Audit;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 use Role::Tiny::With;
 use Path::Class::Dir;
 use Path::Class::File;
@@ -13,7 +13,7 @@ use DateTime;
 with 'PlugAuth::Role::Plugin';
 
 # ABSTRACT: Audit log for authentication/authorization
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 with 'PlugAuth::Role::Plugin';
@@ -147,7 +147,7 @@ PlugAuth::Plugin::Audit - Audit log for authentication/authorization
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
