@@ -2,11 +2,11 @@ package PlugAuth::Plugin::DisableGroup;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 use Role::Tiny::With;
 
 # ABSTRACT: Disable accounts which belong to a group
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 with 'PlugAuth::Role::Plugin';
@@ -43,7 +43,7 @@ PlugAuth::Plugin::DisableGroup - Disable accounts which belong to a group
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
