@@ -1,12 +1,12 @@
 package PlugAuth::Plugin::FlatAuthz;
 
 # ABSTRACT: Authorization using flat files for PlugAuth
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 use Log::Log4perl qw( :easy );
 use Text::Glob qw( match_glob );
 use Clone qw( clone );
@@ -551,7 +551,7 @@ PlugAuth::Plugin::FlatAuthz - Authorization using flat files for PlugAuth
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
