@@ -2,11 +2,11 @@ package PlugAuth::Role::Plugin;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010001;
 use Role::Tiny;
 
 # ABSTRACT: Role for PlugAuth plugins
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 sub init { }
@@ -69,7 +69,7 @@ PlugAuth::Role::Plugin - Role for PlugAuth plugins
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
