@@ -3,7 +3,7 @@ package Test::PlugAuth::Plugin::Auth;
 use strict;
 use warnings;
 use Test::PlugAuth::Plugin;
-use v5.10;
+use 5.010001;
 use Test::Builder;
 use Role::Tiny ();
 use PlugAuth;
@@ -12,7 +12,7 @@ use base qw( Exporter );
 our @EXPORT = qw( run_tests );
 
 # ABSTRACT: Test a PlugAuth Auth plugin for correctness
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 my $Test = Test::Builder->new;
@@ -143,7 +143,7 @@ Test::PlugAuth::Plugin::Auth - Test a PlugAuth Auth plugin for correctness
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
